@@ -11,6 +11,7 @@
 #include "admin/reportinfo.h"
 #include "utils/customemoji.h"
 
+#include <QCoroTask>
 #include <QJsonObject>
 #include <QtQml/qqmlregistration.h>
 
@@ -34,6 +35,7 @@ class AbstractAccount : public QObject
     Q_PROPERTY(QString instanceUri READ instanceUri CONSTANT)
     Q_PROPERTY(int maxPostLength READ maxPostLength NOTIFY fetchedInstanceMetadata)
     Q_PROPERTY(int maxPollOptions READ maxPollOptions NOTIFY fetchedInstanceMetadata)
+    Q_PROPERTY(int maxCharactersPerOption READ maxCharactersPerOption NOTIFY fetchedInstanceMetadata)
     Q_PROPERTY(bool supportsLocalVisibility READ supportsLocalVisibility NOTIFY fetchedInstanceMetadata)
     Q_PROPERTY(QString instanceName READ instanceName NOTIFY fetchedInstanceMetadata)
     Q_PROPERTY(QUrl authorizeUrl READ getAuthorizeUrl NOTIFY registered)
@@ -58,8 +60,13 @@ public:
      * @param locale The user's locale.
      * @param reason If the server requires approval, a reason given to register.
      */
-    Q_INVOKABLE void
-    registerAccount(const QString &username, const QString &email, const QString &password, bool agreement, const QString &locale, const QString &reason);
+    Q_INVOKABLE void registerAccount(const QString &username,
+                                     const QString &email,
+                                     const QString &password,
+                                     bool agreement,
+                                     const QString &locale,
+                                     const QDate &dateOfBirth,
+                                     const QString &reason);
 
     /**
      * @return If the account has successfully authenticated with the server.
@@ -150,6 +157,11 @@ public:
      */
     [[nodiscard]] size_t maxPollOptions() const;
 
+    /**
+     * @return The maximum length of each poll option.
+     */
+    [[nodiscard]] size_t maxCharactersPerOption() const;
+
     /**
      * @return Certain servers (like Pleroma/Akkoma) support an additional visibility type, called Local.
      * @sa Post::Visibility
@@ -418,7 +430,7 @@ public:
     /**
      * @brief Read account from settings to disk.
      */
-    virtual void buildFromSettings() = 0;
+    virtual QCoro::Task<> buildFromSettings() = 0;
 
     /**
      * @return If the account has any follow requests.
@@ -555,6 +567,11 @@ public:
      */
     Q_INVOKABLE bool isFavoriteList(const QString &id);
 
+    /**
+     * @return True if the account is on a server that implements at least the @p api of @p version.
+     */
+    Q_INVOKABLE bool supportsApiVersion(const QString &api, int minimumVersion);
+
     /**
      * @brief Type of account action.
      */
@@ -743,7 +760,10 @@ protected:
     QString m_redirectUri;
     int m_maxMediaAttachments;
     QStringList m_attachmentFilterStrings;
+    QString m_instanceVapidPublicKey;
+    int m_maxCharactersPerOption;
     QString m_streamingUri;
+    QHash<QString, int> m_supportedApiVersions;
 
     // updates and notifications
     void handleNotification(const QJsonDocument &doc);
